# matrixprofile-ts
## What is matrixprofile?
matrixprofile is a Python library for evaluating time series data using the matrix profile algorithms developed by the Keough and Mueen research groups at the University of California-Riverside and the University of New Mexico. Current algorithms implemented include MASS, STMP, STAMP and STAMPI.

## Getting Started
  

### Tutorial
This repo includes a Jupyter Notebook tutorial containing basic examples of the code. This notebook also renders automatically in GitHub. 


*Note: This matrixprofile implementation uses Python 3*
**
This **matrixprofile** library is based on:

Chin-Chia Michael Yeh, Yan Zhu, Liudmila Ulanova, Nurjahan Begum, Yifei Ding, Hoang Anh Dau, Diego Furtado Silva, Abdullah Mueen, Eamonn Keogh (2016). Matrix Profile I: All Pairs Similarity Joins for Time Series: A Unifying View that Includes Motifs, Discords and Shapelets. IEEE ICDM 2016. (http://www.cs.ucr.edu/~eamonn/MatrixProfile.html)
